/* Install/UnInstall script for Tame/2 */

PARSE ARG action
IF RxFuncQuery('SysLoadFuncs') THEN DO
    CALL RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
    CALL SysLoadFuncs
END

CALL SysCls
action = TRANSLATE(LEFT(action,1))
SELECT
    WHEN action = 'I' THEN CALL InstallMe
    WHEN action = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL WhatAction
END
Exit

/* End of main */

/* WhatAction - no action selected */

WhatAction:     PROCEDURE

CALL SysCls
SAY ' '
SAY 'Please enter installation parameter (I=Install, U=UnInstall, other=Exit):'
ans = TRANSLATE(SysGetKey('ECHO'))
SELECT
    WHEN ans = 'I' THEN CALL InstallMe
    WHEN ans = 'U' THEN CALL UnInstallMe
    OTHERWISE CALL NoAction 'Installation stopped.'
END
RETURN

/* End of WhatAction */

/* InstallMe - install Tame/2 */

InstallMe:  PROCEDURE

progname = 'Tame/2'

/* Check RexxUtil.dll version */
SELECT
    WHEN RxFuncQuery("SysUtilVersion") = 1 THEN rexxutil200 = 0
    WHEN SysUtilVersion() < "2.00" THEN rexxutil200 = 0
    OTHERWISE rexxutil200 = 1
END
IF rexxutil200 = 0 THEN DO
    CALL NoAction 'Error!!! Library RexxUtil.dll v.2.00 or higher is required.'
END

IF RIGHT(Directory(),2) = ':\' THEN DO
    SAY 'Error!!! '||progname||' can not be installed in root directory.'
    SAY 'Create directory for '||progname||' and copy files there.'
    CALL NoAction 'Then start this procedure again.'
END

CALL SysCls
SAY 'Welcome to '||progname||' Installation procedure!'
SAY 'Your files are in directory: '||Directory()
SAY 'This procedure will create Folder and Program objects for '||progname||','
SAY 'Press "Y" to start Installation, any other key to exit...'
ans = TRANSLATE(SysGetKey('ECHO'))
IF ans <> 'Y' THEN DO
    CALL NoAction 'Installation stopped.'
END

SAY ' '
SAY 'Checking files:'
required = 'Tame.exe Scanbmp.dll drctl012.dll SCANNER.DAT ENGLISH.INI'
DO i = 1 TO WORDS(required)
    SAY '- '||WORD(required,i)
    IF STREAM(WORD(required,i),'C','QUERY EXISTS') = '' THEN DO
        CALL NoAction 'Error!!! File '||WORD(required,i)||' is missing.'
    END
END
InstallDir = Directory()

SAY ' '
SAY 'Checking image directory'
ImageDir = InstallDir||'\Images'
IF Directory(ImageDir) = '' THEN DO
    dummy = SysMkDir(ImageDir)
END
mydir = Directory(InstallDir)

SAY ' '
inifile = 'TAME.INI'
inikey.1 = 'Language ENGLISH'
inikey.2 = 'Font1 9.WarpSans'
inikey.3 = 'FontCol2 #255 255 132'||'01'x||'#20 20 255'||'01'x||'9.WarpSans'
inikey.4 = 'ImageWin 1 100'
inikey.5 = 'Scan 1 1 0 1 1 1 0 0 3 '||ImageDir
inikey.6 = 'Bubble 3 250'
inikey.0 = 6
SAY 'Writing values to '||inifile
DO i = 1 TO inikey.0
    PARSE VALUE inikey.i WITH key val
    CALL SysIni inifile, 'Settings', key, val
END
CALL SysIni inifile, 'Language', 'ENGLISH', 'English.inf'

DROP inikey.
SAY ' '

/* Check MMFolder class */
CALL SysQueryClassList "clist."
SELECT
    WHEN clist.0 = 0 THEN ismmf = 0
    OTHERWISE DO
        ismmf = 0
        DO i = 1 TO clist.0
            IF WORD(clist.i,1) = 'MMFolder' THEN DO
                ismmf = i
                LEAVE i
            END
        END
    END
END
SELECT
    WHEN ismmf = 0 THEN imgfclass = 'WPFolder'
    OTHERWISE imgfclass = 'MMFolder'
END
DROP clist.

FoldTitle = progname||' 0.9.6'
Icon1 = InstallDir||'\Folder1.ico'
Icon2 = InstallDir||'\Folder2.ico'
Icon = 'ICONFILE='Icon1||';ICONNFILE=1,'||Icon2
Setup = 'OBJECTID=<TAME_2_FOLDER>;'||Icon||''
dummy = SysCreateObject('WPFolder',FoldTitle,'<WP_DESKTOP>',Setup,'U')
SAY 'Folder '||FoldTitle||' - '||rc1(dummy)

FoldTitle = progname||' Images'
Setup = 'OBJECTID=<TAME_2_IMAGES>;ALWAYSSORT=YES'
dummy = SysCreateObject(imgfclass,FoldTitle,'<TAME_2_FOLDER>',Setup,'R')
SAY 'Folder '||FoldTitle||' - '||rc1(dummy)

title.1 = progname
setup.1 = 'OBJECTID=<TAME_2_PROG>;EXENAME='InstallDir'\Tame.exe;ICONFILE='InstallDir'\Tame.ico;STARTUPDIR='InstallDir''
title.2 = progname||'^manual (English)'
setup.2 = 'OBJECTID=<TAME_2_HLPENG>;EXENAME=View.exe;PARAMETERS='InstallDir'\English.inf;STARTUPDIR='InstallDir''
title.0 = 2
DO i = 1 TO title.0
    dummy = SysCreateObject('WPProgram',title.i,'<TAME_2_FOLDER>',setup.i,'U')
    SAY TRANSLATE(title.i,' ','^')||' - '||rc1(dummy)
END

SAY ' '
SAY 'Installation finished. Press any key to exit ...'
ans = SysGetKey('NOECHO')
Exit

/* End of InstallMe */

/* UnInstallMe - uninstall Tame/2 */

UnInstallMe: PROCEDURE

progname = 'Tame/2'
CALL SysCls
SAY 'This is '||progname||' UnInstallation procedure!'
SAY 'Your files are in directory: '||Directory()
SAY 'This procedure will destroy '||progname||' Folder and Program objects'
SAY 'Press "Y" to start UnInstall, any other key to exit...'
ans = TRANSLATE(SysGetKey('ECHO'))
SELECT
    WHEN ans = 'Y' THEN NOP
    OTHERWISE CALL NoAction 'UnInstall aborted.'
END
SAY ' '
SAY 'Destroying Folder and Program objects'
CALL SysDestroyObject '<TAME_2_HLPENG>'
CALL SysDestroyObject '<TAME_2_PROG>'
CALL SysDestroyObject '<TAME_2_IMAGES>'
CALL SysDestroyObject '<TAME_2_FOLDER>'
SAY ' '
SAY 'UnInstallation complete.'
SAY 'You can delete files in directory '||Directory()
SAY 'To install '||progname||' again, start Install I. Press any key to exit...'
ans = SysGetKey('NOECHO')
Exit

/* End of UnInstallMe */

/* NoAction - abort Install */

NoAction:   PROCEDURE

PARSE ARG noinstmsg
dummy = BEEP(450,150)
SAY ' '
SAY noinstmsg
SAY 'Press any key to exit ...'
ans = SysGetKey('NOECHO')
Exit

/* End of NoAction */

/* rc1 - return code - SysCreateObject */

rc1:        PROCEDURE

PARSE ARG rcSysCreateObject
SELECT
    WHEN rcSysCreateObject = 0 THEN RETURN 'Error!'
    OTHERWISE RETURN 'OK'
END

/* End of rc1 */

/* EOF Install.cmd */
